Index: audio.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis-tools/oggenc/audio.c,v
retrieving revision 1.14
diff -u -r1.14 audio.c
--- audio.c	2001/08/13 06:09:13	1.14
+++ audio.c	2001/08/28 18:15:01
@@ -336,8 +336,38 @@
 
 int wav_open(FILE *in, oe_enc_opt *opt, unsigned char *oldbuf, int buflen)
 {
-	unsigned char buf[16];
-	unsigned int len;
+	/* 16 bytes for the old PCM wave format structure
+	 * 2 bytes for extended wave header
+	 * 2 bytes precision
+	 * 4 bytes channel mask
+	 * 16 bytes format guid. In this case MEDISUBTYPE_PCM
+	 * = 40 bytes totally
+	 */
+	unsigned char buf[40];
+
+	/* Define the wave format GUIDs.
+	 * The identation is used to better compare these structs
+	 * with the Microsoft GUIDs.
+	 */
+	static const unsigned char int_pcm_guid[16]=
+	{
+		1,0,0,0 /* The first two bytes (little endian short) are the well known format type. Here 1 for PCM. */
+		,0,0
+		,0x10,0
+		,0x80,0
+		,0,0xaa,0,0x38,0x9b,0x71
+	};
+	static const unsigned char float_pcm_guid[16]=
+	{
+		3,0,0,0
+		,0,0
+		,0x10,0
+		,0x80,0
+		,0,0xaa,0,0x38,0x9b,0x71
+	};
+
+	unsigned int len; /* Length of the header */
+	unsigned int buf_len; /* Length of the data in buf */
 	int samplesize;
 	wav_fmt format;
 	wavfile *wav = malloc(sizeof(wavfile));
@@ -363,14 +393,15 @@
 	 * Please, if you have a program that's creating these 18 byte chunks, send
 	 * a bug report to whoever makes it 
 	 */
-	if(len!=16)
+	if(len!=16 && len!=18 && len!=40)
 		fprintf(stderr, 
 				"Warning: INVALID format chunk in wav header.\n"
 				" Trying to read anyway (may not work)...\n"
 				" The program that created this wav file is broken.\n"
 				" Don't use it, or report a bug.\n");
 
-	if(fread(buf,1,16,in) < len)
+	buf_len=len>sizeof(buf)?sizeof(buf):len;
+	if(fread(buf,1,buf_len,in)<buf_len)
 	{
 		fprintf(stderr, "Warning: Unexpected EOF in reading WAV header\n");
 		return 0;
@@ -378,7 +409,7 @@
 
 	/* Deal with stupid broken apps. Don't use these programs.
 	 */
-	if(len - 16 > 0 && !seek_forward(in, len-16))
+	if( (len - buf_len) > 0 && !seek_forward(in, len-buf_len))
 	    return 0;
 
 	format.format =      READ_U16_LE(buf); 
@@ -387,6 +418,29 @@
 	format.bytespersec = READ_U32_LE(buf+8);
 	format.align =       READ_U16_LE(buf+12);
 	format.samplesize =  READ_U16_LE(buf+14);
+
+	/* The format might be 0xfffe, indicating, that this is a WAVEFORMATEXTENSIBLE chunk.
+	 * In that case we must compare the GUID with the pcm_guid
+	 */
+	if(format.format == (short)0xfffe) /* Need the short cast. Otherwise compares 0xfffffffe with 0xfffe. */
+	{
+		if(len < 40)
+		{
+			fprintf(stderr, "Warning: Unexpected EOF in reading multichannel WAV header\n");
+			return 0;
+		}
+
+		/* If the GUID matches, update the format field for the tests below. */
+		if(memcmp(buf+24,int_pcm_guid,sizeof(int_pcm_guid))==0)
+			format.format = 1;
+		else if(memcmp(buf+24,float_pcm_guid,sizeof(float_pcm_guid))==0)
+			format.format = 3;
+	
+		/* In all other cases leave the format field as it is. The code below
+		 * then returns with an error because the current value 0xfffe
+		 * isn't supported.
+		 */
+	}
 
 	if(!find_wav_chunk(in, "data", &len))
 		return 0; /* EOF */
Index: build_oggenc.bat
===================================================================
RCS file: /usr/local/cvsroot/vorbis-tools/oggenc/build_oggenc.bat,v
retrieving revision 1.1
diff -u -r1.1 build_oggenc.bat
--- build_oggenc.bat	2000/11/18 03:47:35	1.1
+++ build_oggenc.bat	2001/08/28 18:15:01
@@ -10,7 +10,7 @@
 call "c:\program files\microsoft visual studio\vc98\bin\vcvars32.bat"
 echo Setting include/lib paths for Vorbis
 set INCLUDE=%INCLUDE%;%SRCROOT%\ogg\include;%SRCROOT%\vorbis\include
-set LIB=%LIB%;%SRCROOT%\ogg\win32\Static_Release;%SRCROOT%\vorbis\win32\Static_Release
+set LIB=%LIB%;%SRCROOT%\ogg\win32\Static_Release;%SRCROOT%\vorbis\win32\Vorbis_Static_Release;%SRCROOT%\vorbis\win32\VorbisEnc_Static_Release
 echo Compiling...
 msdev oggenc.dsp /useenv /make "oggenc - Win32 Release" /rebuild
 

